@@ -1,13 +1,13 @@
 from django.views.generic import TemplateView
 
-from navutils import Breadcrumb, BreadcrumbsMixin
+from navutils import Breadcrumb, BreadcrumbsMixin, MenuMixin
 
 
 def blank():
     return
 
 
-class BaseMixin(BreadcrumbsMixin, TemplateView):
+class BaseMixin(BreadcrumbsMixin, MenuMixin, TemplateView):
 
     def get_breadcrumbs(self):
         breadcrumbs = super(BaseMixin, self).get_breadcrumbs()
@@ -15,6 +15,10 @@ class BaseMixin(BreadcrumbsMixin, TemplateView):
         return breadcrumbs
 
 
+class Index(BaseMixin):
+    current_menu_item = 'test:index'
+
+
 class BlogMixin(BaseMixin):
     def get_breadcrumbs(self):
         breadcrumbs = super(BlogMixin, self).get_breadcrumbs()
